@@ -1,34 +1,15 @@
 use strict;
+use warnings;
 package Email::Folder;
+{
+  $Email::Folder::VERSION = '0.860';
+}
+# ABSTRACT: read all the messages from a folder as Email::Simple objects
+
 use Carp;
 use Email::Simple;
-use Email::FolderType qw/folder_type/;
+use Email::FolderType 0.6 qw/folder_type/;
 
-use vars qw($VERSION);
-$VERSION = "0.855";
-
-=head1 NAME
-
-Email::Folder - read all the messages from a folder as Email::Simple objects.
-
-=head1 SYNOPSIS
-
- use Email::Folder;
-
- my $folder = Email::Folder->new("some_file");
-
- print join "\n", map { $_->header("Subject") } $folder->messages;
-
-=head1 METHODS
-
-=head2 new($folder, %options)
-
-Takes the name of a folder, and a hash of options
-
-If a 'reader' option is passed in then that is
-used as the class to read in messages with.
-
-=cut
 
 sub new {
     my $class  = shift;
@@ -49,12 +30,6 @@ sub new {
     return bless \%self, $class;
 }
 
-=head2 messages
-
-Returns a list containing all of the messages in the folder.  Can only
-be called once as it drains the iterator.
-
-=cut
 
 sub messages {
     my $self = shift;
@@ -68,12 +43,6 @@ sub messages {
 }
 
 
-=head2 next_message
-
-acts as an iterator.  reads the next message from a folder.  returns
-false at the end of the folder
-
-=cut
 
 sub next_message {
     my $self = shift;
@@ -83,11 +52,69 @@ sub next_message {
 }
 
 
+
+sub bless_message {
+    my $self    = shift;
+    my $message = shift || die "You must pass a message\n";
+
+    return Email::Simple->new($message);
+}
+
+
+
+sub reader {
+    my $self = shift;
+    return $self->{_folder};
+}
+
+1;
+
+
+__END__
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Email::Folder - read all the messages from a folder as Email::Simple objects
+
+=head1 VERSION
+
+version 0.860
+
+=head1 SYNOPSIS
+
+ use Email::Folder;
+
+ my $folder = Email::Folder->new("some_file");
+
+ print join "\n", map { $_->header("Subject") } $folder->messages;
+
+=head1 METHODS
+
+=head2 new($folder, %options)
+
+Takes the name of a folder, and a hash of options
+
+If a 'reader' option is passed in then that is
+used as the class to read in messages with.
+
+=head2 messages
+
+Returns a list containing all of the messages in the folder.  Can only
+be called once as it drains the iterator.
+
+=head2 next_message
+
+acts as an iterator.  reads the next message from a folder.  returns
+false at the end of the folder
+
 =head2 bless_message($message)
 
 Takes a raw RFC822 message and blesses it into a class.
 
-By default this is an Email::Simple object but can easily be overriden
+By default this is an Email::Simple object but can easily be overridden
 in a subclass.
 
 For example, this simple subclass just returns the raw rfc822 messages,
@@ -98,54 +125,38 @@ and exposes the speed of the parser.
  sub bless_message { $_[1] };
  1;
 
-=cut
-
-sub bless_message {
-    my $self    = shift;
-    my $message = shift || die "You must pass a message\n";
-
-    return Email::Simple->new($message);
-}
-
-
 =head2 reader
 
 read-only accessor to the underlying Email::Reader subclass instance
 
-=cut
-
-sub reader {
-    my $self = shift;
-    return $self->{_folder};
-}
-
-1;
-
-__END__
-
-=head1 PERL EMAIL PROJECT
-
-This module is maintained by the Perl Email Project
-
-L<http://emailproject.perl.org/wiki/Email::Folder>
-
-=head1 AUTHORS
-
-Simon Wistow <simon@thegestalt.org>
-
-Richard Clamp <richardc@unixbeard.net>
-
-=head1 COPYING
-
-Copyright 2006, Simon Wistow
-
-Distributed under the same terms as Perl itself.
-
-This software is under no warranty and will probably ruin your life,
-kill your friends, burn your house and bring about the doobie brothers.
-
 =head1 SEE ALSO
 
 L<Email::LocalDelivery>, L<Email::FolderType>, L<Email::Simple>
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Simon Wistow <simon@thegestalt.org>
+
+=item *
+
+Richard Clamp <richardc@unixbeard.net>
+
+=item *
+
+Pali <pali@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2006 by Simon Wistow.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
